@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
-package XS::Parse::Keyword::FromPerl 0.06;
+package XS::Parse::Keyword::FromPerl 0.07;
 
 use v5.26; # XS code needs op_class() and the OPclass_* constants
 use warnings;
@@ -266,6 +266,11 @@ A literal string match, which requires that the following text does not begin
 with an identifier character (thus avoiding prefix-match problems). No value
 is returned.
 
+=head3 XPK_INTRO_MY
+
+Calls the perl C<intro_my()> function immediately. No input is consumed and no
+output value is generated.
+
 =head3 XPK_SEQUENCE
 
    XPK_SEQUENCE(@pieces)
@@ -312,9 +317,9 @@ Attempting to parse this piece type will immediately cause a compile-time
 failure with the given message. This can be used as the final option in
 C<XPK_CHOICE> to ensure a valid match.
 
-=head3 XPK_PARENSCOPE
+=head3 XPK_PARENS
 
-   XPK_PARENSCOPE(@pieces)
+   XPK_PARENS(@pieces)
 
 Expects to find a sequence of pieces, all surrounded by parentheses (round
 brackets, C<( ... )>).
@@ -322,16 +327,16 @@ brackets, C<( ... )>).
 Nothing extra is returned, beyond the values from the individual contained
 pieces.
 
-=head3 XPK_ARGSCOPE
+=head3 XPK_ARGS
 
-   XPK_ARGSCOPE(@pieces)
+   XPK_ARGS(@pieces)
 
-A scope similar to C<XPK_PARENSCOPE> except that the parentheses themselves
+A container similar to C<XPK_PARENS> except that the parentheses themselves
 are optional, similar to perl's parsing of calls to known functions.
 
-=head3 XPK_BRACKETSCOPE
+=head3 XPK_BRACKETS
 
-   XPK_BRACKETSCOPE(@pieces)
+   XPK_BRACKETS(@pieces)
 
 Expects to find a sequence of pieces, all surrounded by square brackets
 (C<[ ... ]>).
@@ -339,18 +344,18 @@ Expects to find a sequence of pieces, all surrounded by square brackets
 Nothing extra is returned, beyond the values from the individual contained
 pieces.
 
-=head3 XPK_BRACESCOPE
+=head3 XPK_BRACES
 
-   XPK_BRACESCOPE(@pieces)
+   XPK_BRACES(@pieces)
 
 Expects to find a sequence of pieces, all surrounded by braces (C<{ ... }>).
 
 Nothing extra is returned, beyond the values from the individual contained
 pieces.
 
-=head3 XPK_CHEVRONSCOPE
+=head3 XPK_CHEVRONS
 
-   XPK_CHEVRONSCOPE(@pieces)
+   XPK_CHEVRONS(@pieces)
 
 Expects to find a sequence of pieces, all surrounded by chevrons (angle
 brackets, C<< < ... > >>).
@@ -384,7 +389,7 @@ foreach (qw(
 # Structural multiple-value pieces
 foreach (qw(
       SEQUENCE OPTIONAL REPEATED CHOICE
-      PARENSCOPE ARGSCOPE BRACKETSCOPE BRACESCOPE CHEVRONSCOPE
+      PARENS ARGS BRACKETS BRACES CHEVRONS
    )) {
    my $name = "XPK_$_";
    push @EXPORT_OK, $name;
@@ -393,6 +398,19 @@ foreach (qw(
    *$name = sub { bless [$name, [@_]], "XS::Parse::Keyword::FromPerl::_Piece" };
 }
 
+# Back-compat wrappers for the old names
+foreach (qw( PAREN ARG BRACKET BRACE CHEVRON )) {
+   my $macroname = "XPK_${_}S";
+   my $funcname  = "XPK_${_}SCOPE";
+   push @EXPORT_OK, $funcname;
+
+   no strict 'refs';
+   *$funcname = sub {
+      warnings::warnif deprecated => "$funcname is now deprecated; use $macroname instead";
+      bless [$macroname, [@_]], "XS::Parse::Keyword::FromPerl::_Piece";
+   };
+}
+
 =head2 Parser Arguments
 
 Each of the values given in the C<@args> array for the "build" phase callback
